@@ -189,6 +189,9 @@ def firing_rate(spike_trains):
     if isinstance(spike_trains, pd.Series):
         spike_trains = pd.DataFrame(spike_trains).T
 
+    if len(spike_trains) == 0:
+        return np.nan
+
     duration = np.sum( spike_trains['duration'] )
 
     trains = spike_trains['spikes']
@@ -248,10 +251,10 @@ def correlation_index(
 
     if normalize:
         trial_num = len(spike_trains)
-        firing_rate = firing_rate(spike_trains)
+        rate = firing_rate(spike_trains)
         duration = get_duration(spike_trains)
 
-        norm = trial_num*(trial_num-1) * firing_rate**2 * coincidence_window * duration
+        norm = trial_num*(trial_num-1) * rate**2 * coincidence_window * duration
 
         ci = Nc / norm
 
