@@ -36,35 +36,25 @@ import warnings
 
 logger = logging.getLogger('thorns')
 
+is_inside_map = False
+
 
 class _FuncWrap(object):
     def __init__(self, func):
         self.func = func
 
     def __call__(self, data):
-        result = _apply_data(self.func, data)
-        return result
+        func = self.func
 
+        global is_inside_map
 
+        is_inside_map = True
+        start = time.time()
+        ans = func(**data)
+        dt = time.time() - start
+        is_inside_map = False
 
-def _func_wrap(func):
-    @functools.wraps(func)
-    def wrap(data):
-        result = _apply_data(func, data)
-        return result
-
-    return wrap
-
-
-
-def _apply_data(func, data):
-
-    start = time.time()
-    ans = func(**data)
-    dt = time.time() - start
-
-    return ans,dt
-
+        return ans,dt
 
 
 
@@ -82,6 +72,7 @@ def _pkl_name(obj, func, cachedir):
     return pkl_name
 
 
+
 def _load_cache(fname):
     logger.info("Loading cache from {}".format(fname))
     with open(fname, 'rb') as f:
@@ -116,7 +107,6 @@ def _serial_map(func, iterable, cfg):
 
 def _serial_isolated_map(func, iterable, cfg):
 
-
     for args in iterable:
         dirname = tempfile.mkdtemp()
         fname = os.path.join(
@@ -179,24 +169,6 @@ def _multiprocessing_map(func, iterable, cfg):
 
 
 
-def _playdoh_map(func, iterable, cfg):
-
-    import playdoh
-
-    wrap = _func_wrap(func)
-
-    jobrun = playdoh.map_async(
-        wrap,
-        iterable,
-        machines=cfg['machines'],
-        codedependencies=cfg['dependencies'],
-    )
-    results = jobrun.get_results()
-
-    for result in results:
-        yield result
-
-
 
 def _ipython_map(func, iterable, cfg):
 
@@ -338,8 +310,11 @@ def _publish_status(status, where='stdout', func_name=""):
 def _get_options(backend, cache, dependencies):
 
     cfg = {}
+    global is_inside_map
 
-    if backend is not None:
+    if is_inside_map:
+        cfg['backend'] = 'serial'
+    elif backend is not None:
         cfg['backend'] = backend
     elif 'THmap' in os.environ:
         cfg['backend'] = os.environ['THmap']
@@ -371,6 +346,8 @@ def _get_options(backend, cache, dependencies):
         cfg['cache'] = 'yes'
 
 
+    cfg['publish_status'] = not is_inside_map
+
     return cfg
 
 
@@ -506,8 +483,6 @@ def map(
         results = _serial_map(func, todos, cfg)
     elif cfg['backend'] in ('multiprocessing', 'm'):
         results = _multiprocessing_map(func, todos, cfg)
-    elif cfg['backend'] == 'playdoh':
-        results = _playdoh_map(func, todos, cfg)
     elif cfg['backend'] in ('ipython', 'ipcluster'):
         results = _ipython_map(func, todos, cfg)
     elif cfg['backend'] == 'serial_isolated':
@@ -522,8 +497,11 @@ def map(
     answers = []
     for how,fname in zip(hows,cache_files):
 
-        _publish_status(status, 'file', func_name=func.func_name)
-        _publish_status(status, 'title', func_name=func.func_name)
+        if cfg['publish_status']:
+            _publish_status(status, 'file', func_name=func.func_name)
+            _publish_status(status, 'title', func_name=func.func_name)
+
+
         if how == 'load':
             result = _load_cache(fname)
             status['loaded'] += 1
@@ -552,9 +530,10 @@ def map(
     out = out.set_index(list(all_kwargs_names))
 
 
-    _publish_status(status, 'file', func_name=func.func_name)
-    _publish_status(status, 'title', func_name=func.func_name)
-    _publish_status(status, 'stdout', func_name=func.func_name)
+    if cfg['publish_status']:
+        _publish_status(status, 'file', func_name=func.func_name)
+        _publish_status(status, 'title', func_name=func.func_name)
+        _publish_status(status, 'stdout', func_name=func.func_name)
 
 
 
